<template>
  <el-bus-crud v-bind="tableConfig" />
</template>

<script>
import MemberRule from '@/components/coupon/member-rule.vue'
export default {
  data() {
    return {
      tableConfig: {
        url: 'flower/api/member/list',
        newUrl: 'flower/api/member/new',
        editUrl: 'flower/api/member/edit',
        deleteUrl: 'flower/api/member/delete',
        columns: [
          { label: '序号', type: 'index' },
          { label: '等级名称', prop: 'name' },
          { label: '成长值', prop: 'startPoint' },
          { label: '等级折扣', prop: 'discountTypeStr' },
          { label: '操作人', prop: 'createName' },
        ],
        beforeOpen: (row, isNew) => {
          if (!isNew) {
            row.consumptionAmountStr = `消费${row.consumptionAmount}元等于${row.growthValue}成长值`
            row.startPointStr = `${
              this.$elBusUtil.isTrueEmpty(row.startPoint) ? '' : row.startPoint
            } ~ ${
              this.$elBusUtil.isTrueEmpty(row.endPoint) ? '' : row.endPoint
            }`
          }
        },
        searchForm: [
          {
            type: 'row',
            items: [{ label: '等级名称：', id: 'name', type: 'input' }],
          },
        ],
        form: [
          {
            label: '会员等级名称：',
            id: 'name',
            type: 'input',
            rules: { required: true, message: '请输入会员等级名称' },
          },
          {
            label: '成长值范围：',
            id: 'startPoint',
            component: 'el-bus-number-range',
            el: {
              unit: '',
              separator: '<= 成长值范围 <',
              inputAttrs: {
                controls: false,
              },
            },
            commonFormat: true,
            commonFormatProps: ['startPoint', 'endPoint'],
            commonRules: true,
            commonRulesLevel: 1,
            str: true,
          },
          {
            label: '折扣类型：',
            id: 'discountType',
            type: 'bus-select-dict',
            el: {
              code: 'DISCOUNT_TYPE',
              style: 'width:100%',
            },
            str: true,
            rules: { required: true, message: '请选择折扣类型' },
            on: {
              change: (e, updateForm) => {
                updateForm({
                  discountRatio: undefined,
                  discountAmount: undefined,
                })
              },
            },
          },
          {
            label: '会员折扣：',
            id: 'discountRatio',
            type: 'input-number',
            el: {
              precision: 0,
              min: 0,
              max: 100,
              controls: false,
            },
            unit: '%',
            rules: {
              required: true,
              message: '请输入会员折扣',
              trigger: 'blur',
            },
            hidden: (row) => row.discountType !== 'ratio',
          },
          {
            label: '会员优惠：',
            id: 'discountAmount',
            type: 'input-number',
            el: {
              precision: 2,
              min: 0,
              controls: false,
            },
            unit: '元',
            rules: {
              required: true,
              message: '请输入会员优惠',
              trigger: 'blur',
            },
            hidden: (row) => row.discountType !== 'amount',
          },
          {
            label: '会员规则：',
            id: 'consumptionAmount',
            component: MemberRule,
            commonRules: true,
            commonFormat: true,
            commonFormatProps: ['consumptionAmount', 'growthValue'],
            str: true,
          },
          {
            label: '降级规则：',
            id: 'downgradeValue',
            type: 'input-number',
            el: {
              precision: 0,
              min: 0,
              controls: false,
            },
            unit: '成长值',
            rules: {
              required: true,
              message: '请输入降级规则',
              trigger: 'blur',
            },
          },
        ],
      },
    }
  },
}
</script>
